# Data Pipeline user

A python package with utilities for building and managing data pipelines

## Features
-Data cleaning utilities
-ETL helpers
-SQL query builders

Check out the [example_script](examples/example_usage.py)

## Installation
```bash
pip install data-pipeline-user


